@@ -1,4 +1,11 @@
 package Tapper::TestSuite::AutoTest;
+BEGIN {
+  $Tapper::TestSuite::AutoTest::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::TestSuite::AutoTest::VERSION = '4.0.1';
+}
+# ABSTRACT: Tapper - Complete OS testing in a box via autotest
 
 use warnings;
 use strict;
@@ -16,70 +23,6 @@ use Digest::MD5 'md5_hex';
 
 extends 'Tapper::Base';
 
-our $VERSION = '3.000012';
-
-
-=head1 NAME
-
-Tapper::TestSuite::AutoTest - Tapper - Complete OS testing in a box via autotest
-
-=head1 SYNOPSIS
-
-You most likely want to run the frontend cmdline tool like this
-
-=over 4
-
-=item * Run an autotest subtest and report results to Tapper:
-
-  $ tapper-testsuite-autotest -t hackbench
-
-=item * Run multiple autotest subtests and report results to Tapper:
-
-  $ tapper-testsuite-autotest -t hackbench -t hwclock
-
-=back
-
-=head1 ABOUT
-
-This module wraps autotest to make its (sub) tests available for Tapper.
-
-The commandline tool simply calls the single steps like this:
-
-    use Tapper::TestSuite::AutoTest;
-
-    my $wrapper = Tapper::TestSuite::AutoTest->new();
-    my $args    = $wrapper->parse_args();
-    $args       = $wrapper->install($args);
-    $args       = $wrapper->run($args);
-
-The reporting evaluates several environment variables:
-
-  TAPPER_REPORT_SERVER
-  TAPPER_REPORT_API_PORT
-  TAPPER_REPORT_PORT
-  TAPPER_TESTRUN
-  TAPPER_REPORT_GROUP
-
-with some sensible defaults. They are automatically provided when
-using Tapper automation. 
-
-In case you run it manually the most important variable is
-C<TAPPER_REPORT_SERVER> pointing to your central Tapper server.
-
-See the Tapper manual for more details.
-
-=head1 FUNCTIONS
-
-=head2 copy_client
-
-Move the client to where it belongs.
-
-@param string - download directory
-@param string - target directory
-
-@return die() in case of error
-
-=cut
 
 sub copy_client
 {
@@ -100,15 +43,6 @@ sub copy_client
 }
 
 
-=head2 install
-
-Install the autotest framework from a given source into a given target
-
-@param hash ref - args
-
-@return hash ref - args
-
-=cut
 
 sub install
 {
@@ -154,16 +88,6 @@ sub install
 }
 
 
-=head2 report_away
-
-Send the actual report to reports receiver framework.
-
-@param hash ref - args
-
-@return success - int - report id
-@return error   - die()
-
-=cut
 
 sub report_away
 {
@@ -184,17 +108,10 @@ sub report_away
         ($report_id) = $report_id =~ /(\d+)$/;
         $sock->print($gzipped_content);
         $sock->close();
+        $self->log->debug( "Report $report_id (http://".$args->{report_server}."/tapper/reports/id/$report_id)");
         return $report_id;
 }
 
-=head2 upload_files
-
-Upload the stats file to reports framework.
-
-@param int       - report id
-@param hash ref - args
-
-=cut
 
 sub upload_files
 {
@@ -271,35 +188,54 @@ sub upload_files
         return;
 }
 
-=head2 send_results
 
-Send the test results to Tapper.
+sub get_machine_name
+{
+        my $etc_tapper = "/etc/tapper";
 
-@param hash ref - args
+        my $hostname = hostname();
+        $hostname =~ s/\..*$//; # no FQDN
+        # combined machine name in Tapper automation guest environment
+        if ($ENV{TAPPER_HOSTNAME}) {
+                $hostname = "$ENV{TAPPER_HOSTNAME}:$hostname"
+        } elsif ( -r $etc_tapper ) {
+                my @tapper_config = ();
+                my $TAPPERCFG;
+                open $TAPPERCFG, "<", $etc_tapper and do {
+                        local $/;
+                        @tapper_config = <$TAPPERCFG>;
+                        close $TAPPERCFG;
+                };
+                my ($machinename) =
+                 map {
+                      my $m = $_ ; $m =~ s/^[^:]*:// ; $m
+                     }
+                  grep {
+                          /hostname:/
+                  } @tapper_config;
+                $hostname = "${machinename}:$hostname";
+        }
+        return $hostname;
+}
 
-@return hash ref - args
-
-=cut
 
 sub send_results
 {
         my ($self, $test, $args) = @_;
         my $report;
 
-
         my $tar             = Archive::Tar->new;
         $args->{result_dir} = $args->{target}."/results/default";
         my $result_dir      = $args->{result_dir};
-        my $hostname        = hostname();
+        my $hostname        = get_machine_name;
         my $testrun_id      = $args->{testrun_id};
-
         my $report_group    = $args->{report_group};
 
         my $report_meta = "Version 13
 1..1
 # Tapper-Suite-Name: Autotest-$test
 # Tapper-Machine-Name: $hostname
-# Tapper-Suite-Version: $VERSION
+# Tapper-Suite-Version: ".$Tapper::TestSuite::AutoTest::VERSION."
 ok 1 - Tapper metainfo
 ";
         $report_meta .= $testrun_id   ? "# Tapper-Reportgroup-Testrun: $testrun_id\n"     : '';
@@ -325,15 +261,6 @@ ok 1 - Tapper metainfo
         return $args;
 }
 
-=head2 autotest_meta
-
-Add meta information from files generated by autotest.
-
-@param hash ref - args
-
-@return string - Tapper TAP metainfo headers
-
-=cut
 
 sub autotest_meta
 {
@@ -356,20 +283,17 @@ sub autotest_meta
         }
 
         # --- cpu info ---
-        my @lines      = slurp("$result_dir/sysinfo/cpuinfo");
-        my $is_arm_cpu = grep { /Processor.*:.*ARM/ } @lines;
-        my $entry      = $is_arm_cpu ? "Processor" : "model name";
-        my @cpuinfo    = map { chomp ; s/^$entry.*: *//; $_ } grep { /$entry.*:/ } @lines;
-        $meta         .= "# Tapper-cpuinfo: ".@cpuinfo." cores [".$cpuinfo[0]."]\n" if @cpuinfo;
-
+        my $cpuinfofile    = "$result_dir/sysinfo/cpuinfo";
+        if (-e $cpuinfofile) {
+                my @lines      = slurp($cpuinfofile);
+                my $is_arm_cpu = grep { /Processor.*:.*ARM/ } @lines;
+                my $entry      = $is_arm_cpu ? "Processor" : "model name";
+                my @cpuinfo    = map { chomp ; s/^$entry.*: *//; $_ } grep { /$entry.*:/ } @lines;
+                $meta         .= "# Tapper-cpuinfo: ".@cpuinfo." cores [".$cpuinfo[0]."]\n" if @cpuinfo;
+        }
         return $meta;
 }
 
-=head2 print_help
-
-Print help and die.
-
-=cut
 
 sub print_help
 {
@@ -385,13 +309,6 @@ sub print_help
         exit;
 }
 
-=head2 parse_args
-
-Parse command line arguments and Tapper ENV variables.
-
-@return hash ref - args
-
-=cut
 
 sub parse_args
 {
@@ -430,16 +347,6 @@ sub parse_args
 }
 
 
-=head2 run
-
-Run the requested autotest test(s), collect their results and report
-them.
-
-@param hash ref - args
-
-@return hash ref - args
-
-=cut
 
 sub run
 {
@@ -455,58 +362,149 @@ sub run
         return $args;
 }
 
+1; # End of Tapper::TestSuite::AutoTest
 
+__END__
+=pod
 
-=head1 BUGS
+=encoding utf-8
 
-Please report any bugs or feature requests to C<bug-tapper-testsuite-autotest at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Tapper-TestSuite-AutoTest>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=head1 NAME
 
+Tapper::TestSuite::AutoTest - Tapper - Complete OS testing in a box via autotest
 
+=head1 SYNOPSIS
 
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Tapper::TestSuite::AutoTest
-
-
-You can also look for information at:
+You most likely want to run the frontend cmdline tool like this
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * Run an autotest subtest and report results to Tapper:
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Tapper-TestSuite-AutoTest>
+  $ tapper-testsuite-autotest -t hackbench
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item * Run multiple autotest subtests and report results to Tapper:
 
-L<http://annocpan.org/dist/Tapper-TestSuite-AutoTest>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Tapper-TestSuite-AutoTest>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Tapper-TestSuite-AutoTest/>
+  $ tapper-testsuite-autotest -t hackbench -t hwclock
 
 =back
 
+=head1 ABOUT
+
+This module wraps autotest to make its (sub) tests available for Tapper.
+
+The commandline tool simply calls the single steps like this:
+
+    use Tapper::TestSuite::AutoTest;
+
+    my $wrapper = Tapper::TestSuite::AutoTest->new();
+    my $args    = $wrapper->parse_args();
+    $args       = $wrapper->install($args);
+    $args       = $wrapper->run($args);
+
+The reporting evaluates several environment variables:
+
+  TAPPER_REPORT_SERVER
+  TAPPER_REPORT_API_PORT
+  TAPPER_REPORT_PORT
+  TAPPER_TESTRUN
+  TAPPER_REPORT_GROUP
+
+with some sensible defaults. They are automatically provided when
+using Tapper automation.
+
+In case you run it manually the most important variable is
+C<TAPPER_REPORT_SERVER> pointing to your central Tapper server.
+
+See the Tapper manual for more details.
+
+=head1 FUNCTIONS
+
+=head2 copy_client
+
+Move the client to where it belongs.
+
+@param string - download directory
+@param string - target directory
+
+@return die() in case of error
+
+=head2 install
+
+Install the autotest framework from a given source into a given target
+
+@param hash ref - args
+
+@return hash ref - args
+
+=head2 report_away
+
+Send the actual report to reports receiver framework.
+
+@param hash ref - args
+
+@return success - int - report id
+@return error   - die()
+
+=head2 upload_files
+
+Upload the stats file to reports framework.
+
+@param int       - report id
+@param hash ref - args
+
+=head2 get_machine_name
+
+Return hostname for metainfo in typical Tapper notation, i.e., just
+the hostname (without FQDN) in host context or C<host:guest> (colon
+separated) in guest context.
+
+=head2 send_results
+
+Send the test results to Tapper.
+
+@param hash ref - args
+
+@return hash ref - args
+
+=head2 autotest_meta
+
+Add meta information from files generated by autotest.
+
+@param hash ref - args
+
+@return string - Tapper TAP metainfo headers
+
+=head2 print_help
+
+Print help and die.
+
+=head2 parse_args
+
+Parse command line arguments and Tapper ENV variables.
+
+@return hash ref - args
+
+=head2 run
+
+Run the requested autotest test(s), collect their results and report
+them.
+
+@param hash ref - args
+
+@return hash ref - args
 
 =head1 AUTHOR
 
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
+AMD OSRC Tapper Team <tapper@amd64.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
 
-This program is released under the following license: freebsd
+This is free software, licensed under:
 
+  The (two-clause) FreeBSD License
 
 =cut
 
-1; # End of Tapper::TestSuite::AutoTest
